package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Feb 24, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Reads in the config file and returns the config as a struct
*
- if run under the other profile. For example application-dev.yaml
*
type CommonDto struct {
Config struct {
Kafka struct {
}
Udp struct {
}
}
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.